summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNinad Sathaye <ninad@nanorex.com>2008-09-24 18:53:34 +0000
committerNinad Sathaye <ninad@nanorex.com>2008-09-24 18:53:34 +0000
commitf575eda394d1b234e94e3306ddce5889825d0113 (patch)
treee04c94d0aa2b8b07215afba07e0c66508593cb9c
parente9f081f064150f9cf1b362cffddc75db188c7116 (diff)
downloadnanoengineer-f575eda394d1b234e94e3306ddce5889825d0113.tar.gz
nanoengineer-f575eda394d1b234e94e3306ddce5889825d0113.zip
bug fixes after module renaming
-rw-r--r--cad/src/dna/commands/BuildDuplex/DnaDuplex_EditCommand.py4
-rw-r--r--cad/src/dna/commands/DnaSegment/DnaSegment_EditCommand.py6
-rw-r--r--cad/src/dna/commands/DnaStrand/DnaStrand_EditCommand.py2
-rw-r--r--cad/src/dna/commands/MakeCrossovers/MakeCrossovers_Command.py2
-rw-r--r--cad/src/dna/generators/Dna_Generator.py14
5 files changed, 14 insertions, 14 deletions
diff --git a/cad/src/dna/commands/BuildDuplex/DnaDuplex_EditCommand.py b/cad/src/dna/commands/BuildDuplex/DnaDuplex_EditCommand.py
index 3e390c33b..e252b90f3 100644
--- a/cad/src/dna/commands/BuildDuplex/DnaDuplex_EditCommand.py
+++ b/cad/src/dna/commands/BuildDuplex/DnaDuplex_EditCommand.py
@@ -557,9 +557,9 @@ class DnaDuplex_EditCommand(EditCommand):
if dnaForm == 'B-DNA':
if dnaModel == 'PAM3':
- dna = B_Dna_PAM3()
+ dna = B_Dna_PAM3_Generator()
elif dnaModel == 'PAM5':
- dna = B_Dna_PAM5()
+ dna = B_Dna_PAM5_Generator()
else:
print "bug: unknown dnaModel type: ", dnaModel
else:
diff --git a/cad/src/dna/commands/DnaSegment/DnaSegment_EditCommand.py b/cad/src/dna/commands/DnaSegment/DnaSegment_EditCommand.py
index b88e1d56b..1c6390076 100644
--- a/cad/src/dna/commands/DnaSegment/DnaSegment_EditCommand.py
+++ b/cad/src/dna/commands/DnaSegment/DnaSegment_EditCommand.py
@@ -664,9 +664,9 @@ class DnaSegment_EditCommand(State_preMixin, EditCommand):
if dnaForm == 'B-DNA':
if dnaModel == 'PAM3':
- dna = B_Dna_PAM3()
+ dna = B_Dna_PAM3_Generator()
elif dnaModel == 'PAM5':
- dna = B_Dna_PAM5()
+ dna = B_Dna_PAM5_Generator()
else:
print "bug: unknown dnaModel type: ", dnaModel
else:
@@ -746,7 +746,7 @@ class DnaSegment_EditCommand(State_preMixin, EditCommand):
"""
assert self.struct
- self.dna = B_Dna_PAM3()
+ self.dna = B_Dna_PAM3_Generator()
number_of_basePairs_from_struct,\
numberOfBases, \
diff --git a/cad/src/dna/commands/DnaStrand/DnaStrand_EditCommand.py b/cad/src/dna/commands/DnaStrand/DnaStrand_EditCommand.py
index 17a2dabdf..2171285d9 100644
--- a/cad/src/dna/commands/DnaStrand/DnaStrand_EditCommand.py
+++ b/cad/src/dna/commands/DnaStrand/DnaStrand_EditCommand.py
@@ -342,7 +342,7 @@ class DnaStrand_EditCommand(State_preMixin, EditCommand):
# made with)
name = self.name
- self.dna = B_Dna_PAM3_SingleStrand()
+ self.dna = B_Dna_PAM3_SingleStrand_Generator()
numberOfBases, \
dnaForm, \
diff --git a/cad/src/dna/commands/MakeCrossovers/MakeCrossovers_Command.py b/cad/src/dna/commands/MakeCrossovers/MakeCrossovers_Command.py
index bcc78b52a..5209d80aa 100644
--- a/cad/src/dna/commands/MakeCrossovers/MakeCrossovers_Command.py
+++ b/cad/src/dna/commands/MakeCrossovers/MakeCrossovers_Command.py
@@ -281,7 +281,7 @@ class MakeCrossovers_Command(SelectChunks_Command,
@Note: This method is copied from DnaDuplex.py
"""
- #Moved from B_Dna_PAM3_SingleStrand to here, to fix bugs like
+ #Moved from B_Dna_PAM3_SingleStrand_Generator to here, to fix bugs like
#2711 in segment resizing-- Ninad 2008-04-14
assert atm1.element.role == 'strand' and atm2.element.role == 'strand'
#Initialize all possible bond points to None
diff --git a/cad/src/dna/generators/Dna_Generator.py b/cad/src/dna/generators/Dna_Generator.py
index 4c720027c..0abc22322 100644
--- a/cad/src/dna/generators/Dna_Generator.py
+++ b/cad/src/dna/generators/Dna_Generator.py
@@ -124,7 +124,7 @@ class Dna_Generator:
- the optional argument resizeEndStrandAtom and assignment of
self.resizeEndStrand1Atom needs to be cleaned up.
- refactoring cleanup and more renaming etc planned post FNANO
- - See also comments in B_Dna_PAM3_SingleStrand
+ - See also comments in B_Dna_PAM3_SingleStrand_Generator
"""
self.assy = group.assy
assy = group.assy
@@ -325,7 +325,7 @@ class Dna_Generator:
def _replace_overlapping_axisAtoms_of_new_dna(self, new_endBaseAtomList):
"""
- @see: B_Dna_PAM3_SingleStrand._replace_overlapping_axisAtoms_of_new_dna()
+ @see: B_Dna_PAM3_SingleStrand_Generator._replace_overlapping_axisAtoms_of_new_dna()
"""
pass
@@ -347,7 +347,7 @@ class Dna_Generator:
only a duplex and thats why the name 'duplex'
@see: self.modify()
- @see: B_Dna_PAM3_SingleStrand._fuse_new_dna_with_original_duplex()
+ @see: B_Dna_PAM3_SingleStrand_Generator._fuse_new_dna_with_original_duplex()
"""
@@ -581,7 +581,7 @@ class Dna_Generator:
@see: self._fuse_new_dna_with_original_duplex()
@see: self._bond_atoms_in_atomPairs() which calls this
"""
#Moved from B_Dna_PAM3_SingleStrand to here, to fix bugs like
#2711 in segment resizing-- Ninad 2008-04-14
assert atm1.element.role == 'strand' and atm2.element.role == 'strand'
#Initialize all possible bond points to None
@@ -868,8 +868,8 @@ class Dna_Generator:
needs to be deleted. The latter is the case while resizing a
single strand of a Dna.
@see: self._remove_bases_from_dna() where this is called.
- @see: B_Dna_PAM3._strand_neighbors_to_delete()
- @see: B_Dna_PAM3_SingleStrand._strand_neighbors_to_delete()
+ @see: B_Dna_PAM3_Generator._strand_neighbors_to_delete()
+ @see: B_Dna_PAM3_SingleStrand_Generator._strand_neighbors_to_delete()
"""
return ()
@@ -1037,7 +1037,7 @@ class Dna_Generator:
#Perhaps computing this strand atom always be done at a later
#stage. But I am unsure if this will cause any bugs. So not
#changing the original implementation .
#See B_Dna_PAM3.orient_for_modify() for details.
#This NEEDS CLEANUP -- Ninad 2008-06-02
self._determine_axis_and_strandA_endAtoms_at_end_1(self.baseList[0])
@@ -581,7 +581,7 @@ class Dna_Generator:
"""
- #Moved from B_Dna_PAM3_SingleStrand to here, to fix bugs like
+ #Moved from B_Dna_PAM3_SingleStrand_Generator to here, to fix bugs like
#2711 in segment resizing-- Ninad 2008-04-14
assert atm1.element.role == 'strand' and atm2.element.role == 'strand'
@@ -1037,7 +1037,7 @@ class Dna_Generator:
#stage. But I am unsure if this will cause any bugs. So not
#changing the original implementation .
- #See B_Dna_PAM3.orient_for_modify() for details.
+ #See B_Dna_PAM3_Generator.orient_for_modify() for details.
#This NEEDS CLEANUP -- Ninad 2008-06-02
self._determine_axis_and_strandA_endAtoms_at_end_1(self.baseList[0])